@@ -43,7 +43,7 @@ class Enumeration(GenericEnumeration):
         return H2_DEFAULT_SCHEMA
 
     def getPasswordHashes(self):
-        warnMsg = "on H2 it is not possible to list password hashes"
+        warnMsg = "on H2 it is not possible to enumerate password hashes"
         logger.warn(warnMsg)
 
         return {}
